@@ -23,9 +23,9 @@ class ImageDigestMirrorSet(Resource):
         self.image_digest_mirrors = image_digest_mirrors
         super().__init__(**kwargs)
 
-    def to_dict(self) -> None:
+    def to_dict(self):
         super().to_dict()
-        if not self.kind_dict and not self.yaml_file:
+        if not self.yaml_file:
             if not self.image_digest_mirrors:
                 raise MissingRequiredArgumentError(argument="image_digest_mirrors")
             self.res["spec"] = {"imageDigestMirrors": self.image_digest_mirrors}
